@@ -25,6 +25,8 @@ chg_log_to_date_prompt_id = "16C4D8A0477EE34A0ACC88AD6F90ECC8"
 chg_log_proj_prompt_id = "35F616224B5A80B5FDCA6BA77BC799F9"
 chg_log_obj_prompt_id = "F21128A94659B9EC5CA6EEA1653B1680"
 
+base_url= "http://" + server + ":" + port + "/MicroStrategyLibrary/api"
+
 cube_name = "TestCube_ds"
 
 conn_det = {"username": username, "password": password,
@@ -46,7 +48,7 @@ change_query={"chg_log_from_date":chg_log_from_date
               ,"mtdi_id":None
               ,"cube_name":"TestCube"}
 
-conn=mig.standard_login(conn_det=conn_det,project_id=change_log_report["chg_log_rep_proj_id"])
+conn=mig.standard_login(base_url=base_url,username=username,password=password,project_id="B19DEDCC11D4E0EFC000EB9495D0F44F")
 
 #pass over the parameters
 mig_rep.set_md_rep_params(conn=conn,change_query=change_query,change_log_report=change_log_report)
