@@ -12,12 +12,12 @@ from mstr_robotics.mstr_classes import get_conn
 from datetime import datetime
 from mstr_robotics.helper import str_func
 import pandas as pd
-
+from typing import Optional
 
 class open_conn():
 
-    def standard_login(self,conn_det,project_id=None):
-        return get_conn(self,conn_det=conn_det, project_id=project_id)
+    def standard_login(self,base_url,project_id=None,*args,**kwargs):
+        return get_conn(self,base_url=base_url, project_id=project_id,*args,**kwargs)
 
 class prepare_mig_obj():
 
